from .Items import SongData
from typing import Dict


# Auto Generated
SONG_DATA: Dict[str, SongData] = {
    "Magical Wonderland": SongData(2900051, "0-48", "Default Music", True, 1, 3, None),
    "Iyaiya": SongData(2900052, "0-0", "Default Music", True, 1, 4, None),
    "Wonderful Pain": SongData(2900053, "0-2", "Default Music", False, 1, 3, None),
    "Breaking Dawn": SongData(2900054, "0-3", "Default Music", True, 2, 4, None),
    "One-Way Subway": SongData(2900055, "0-4", "Default Music", True, 1, 4, None),
    "Frost Land": SongData(2900056, "0-1", "Default Music", False, 1, 3, 6),
    "Heart-Pounding Flight": SongData(2900057, "0-5", "Default Music", True, 2, 5, None),
    "Pancake is Love": SongData(2900058, "0-29", "Default Music", True, 2, 4, 7),
    "Shiguang Tuya": SongData(2900059, "0-6", "Default Music", True, 2, 5, None),
    "Evolution": SongData(2900060, "0-37", "Default Music", False, 2, 4, 7),
    "Dolphin and Broadcast": SongData(2900061, "0-7", "Default Music", True, 2, 5, None),
    "Yuki no Shizuku Ame no Oto": SongData(2900062, "0-8", "Default Music", True, 2, 4, 6),
    "Best One feat.tooko": SongData(2900063, "0-43", "Default Music", False, 3, 5, None),
    "Candy-coloured Love Theory": SongData(2900064, "0-31", "Default Music", False, 2, 4, 6),
    "Night Wander": SongData(2900065, "0-38", "Default Music", False, 3, 5, 7),
    "Dohna Dohna no Uta": SongData(2900066, "0-46", "Default Music", False, 2, 4, 6),
    "Spring Carnival": SongData(2900067, "0-9", "Default Music", False, 2, 4, 7),
    "DISCO NIGHT": SongData(2900068, "0-30", "Default Music", True, 2, 4, 7),
    "Koi no Moonlight": SongData(2900069, "0-49", "Default Music", False, 2, 5, 8),
    "Lian Ai Audio Navigation": SongData(2900070, "0-10", "Default Music", False, 3, 5, 7),
    "Lights of Muse": SongData(2900071, "0-11", "Default Music", True, 4, 6, 8),
    "midstream jam": SongData(2900072, "0-12", "Default Music", False, 2, 5, 8),
    "Nihao": SongData(2900073, "0-40", "Default Music", False, 3, 5, 7),
    "Confession": SongData(2900074, "0-13", "Default Music", False, 3, 5, 8),
    "Galaxy Striker": SongData(2900075, "0-32", "Default Music", False, 4, 7, 9),
    "Departure Road": SongData(2900076, "0-14", "Default Music", True, 2, 5, 8),
    "Bass Telekinesis": SongData(2900077, "0-15", "Default Music", False, 2, 5, 8),
    "Cage of Almeria": SongData(2900078, "0-16", "Default Music", True, 3, 5, 7),
    "Ira": SongData(2900079, "0-17", "Default Music", True, 4, 6, 8),
    "Blackest Luxury Car": SongData(2900080, "0-18", "Default Music", True, 3, 6, 8),
    "Medicine of Sing": SongData(2900081, "0-19", "Default Music", False, 3, 6, 8),
    "irregulyze": SongData(2900082, "0-20", "Default Music", True, 3, 6, 8),
    "I don't care about Christmas though": SongData(2900083, "0-47", "Default Music", False, 4, 6, 8),
    "Imaginary World": SongData(2900084, "0-21", "Default Music", True, 4, 6, 8),
    "Dysthymia": SongData(2900085, "0-22", "Default Music", True, 4, 7, 9),
    "From the New World": SongData(2900086, "0-42", "Default Music", False, 2, 5, 7),
    "NISEGAO": SongData(2900087, "0-33", "Default Music", True, 4, 7, 9),
    "Say! Fanfare!": SongData(2900088, "0-44", "Default Music", False, 4, 6, 9),
    "Star Driver": SongData(2900089, "0-34", "Default Music", True, 5, 7, 9),
    "Formation": SongData(2900090, "0-23", "Default Music", True, 4, 6, 9),
    "Shinsou Masui": SongData(2900091, "0-24", "Default Music", True, 4, 6, 10),
    "Mezame Eurythmics": SongData(2900092, "0-50", "Default Music", False, 4, 6, 9),
    "Shenri Kuaira -repeat-": SongData(2900093, "0-51", "Default Music", False, 5, 7, 9),
    "Latitude": SongData(2900094, "0-25", "Default Music", True, 3, 6, 9),
    "Aqua Stars": SongData(2900095, "0-39", "Default Music", False, 5, 7, 10),
    "Funkotsu Saishin Casino": SongData(2900096, "0-26", "Default Music", False, 5, 7, 10),
    "Clock Room & Spiritual World": SongData(2900097, "0-27", "Default Music", True, 4, 6, 9),
    "INTERNET OVERDOSE": SongData(2900098, "0-52", "Default Music", False, 3, 6, 9),
    "Tu Hua": SongData(2900099, "0-35", "Default Music", True, 4, 7, 9),
    "Mujinku-Vacuum": SongData(2900100, "0-28", "Default Music", False, 5, 7, 11),
    "MilK": SongData(2900101, "0-36", "Default Music", False, 5, 7, 9),
    "umpopoff": SongData(2900102, "0-41", "Default Music", False, None, 7, None),
    "Mopemope": SongData(2900103, "0-45", "Default Music", False, 4, 7, 9),
    "The Happycore Idol": SongData(2900105, "43-0", "MD Plus Project", True, 2, 5, 7),
    "Amatsumikaboshi": SongData(2900106, "43-1", "MD Plus Project", True, 4, 6, 8),
    "ARIGA THESIS": SongData(2900107, "43-2", "MD Plus Project", True, 3, 6, 10),
    "Night of Nights": SongData(2900108, "43-3", "MD Plus Project", False, 4, 7, 10),
    "#Psychedelic_Meguro_River": SongData(2900109, "43-4", "MD Plus Project", False, 3, 6, 8),
    "can you feel it": SongData(2900110, "43-5", "MD Plus Project", False, 4, 6, 8),
    "Midnight O'clock": SongData(2900111, "43-6", "MD Plus Project", True, 3, 6, 8),
    "Rin": SongData(2900112, "43-7", "MD Plus Project", True, 5, 7, 10),
    "Smile-mileS": SongData(2900113, "43-8", "MD Plus Project", False, 6, 8, 10),
    "Believing and Being": SongData(2900114, "43-9", "MD Plus Project", True, 4, 6, 9),
    "Catalyst": SongData(2900115, "43-10", "MD Plus Project", False, 5, 7, 9),
    "don't!stop!eroero!": SongData(2900116, "43-11", "MD Plus Project", True, 5, 7, 9),
    "pa pi pu pi pu pi pa": SongData(2900117, "43-12", "MD Plus Project", False, 6, 8, 10),
    "Sand Maze": SongData(2900118, "43-13", "MD Plus Project", True, 6, 8, 10),
    "Diffraction": SongData(2900119, "43-14", "MD Plus Project", True, 5, 8, 10),
    "AKUMU": SongData(2900120, "43-15", "MD Plus Project", False, 4, 6, 8),
    "Queen Aluett": SongData(2900121, "43-16", "MD Plus Project", True, 7, 9, 11),
    "DROPS": SongData(2900122, "43-17", "MD Plus Project", False, 2, 5, 8),
    "Frightfully-insane Flan-chan's frightful song": SongData(2900123, "43-18", "MD Plus Project", False, 5, 7, 10),
    "snooze": SongData(2900124, "43-19", "MD Plus Project", False, 5, 7, 10),
    "Kuishinbo Hacker feat.Kuishinbo Akachan": SongData(2900125, "43-20", "MD Plus Project", True, 5, 7, 9),
    "Inu no outa": SongData(2900126, "43-21", "MD Plus Project", True, 3, 5, 7),
    "Prism Fountain": SongData(2900127, "43-22", "MD Plus Project", True, 7, 9, 11),
    "Gospel": SongData(2900128, "43-23", "MD Plus Project", False, 4, 6, 9),
    "East Ai Li Lovely": SongData(2900130, "62-0", "Happy Otaku Pack Vol.17", False, 2, 4, 7),
    "Mori Umi no Fune": SongData(2900131, "62-1", "Happy Otaku Pack Vol.17", True, 5, 7, 9),
    "Ooi": SongData(2900132, "62-2", "Happy Otaku Pack Vol.17", True, 5, 7, 10),
    "Numatta!!": SongData(2900133, "62-3", "Happy Otaku Pack Vol.17", True, 5, 7, 9),
    "SATELLITE": SongData(2900134, "62-4", "Happy Otaku Pack Vol.17", False, 5, 7, 9),
    "Fantasia Sonata Colorful feat. V!C": SongData(2900135, "62-5", "Happy Otaku Pack Vol.17", True, 6, 8, 11),
    "MuseDash ka nanika hi": SongData(2900137, "61-0", "Ola Dash", True, 4, 7, 10),
    "Aleph-0": SongData(2900138, "61-1", "Ola Dash", True, 7, 9, 11),
    "Buttoba Supernova": SongData(2900139, "61-2", "Ola Dash", False, 5, 7, 10),
    "Rush-Hour": SongData(2900140, "61-3", "Ola Dash", False, 4, 7, 10),
    "3rd Avenue": SongData(2900141, "61-4", "Ola Dash", False, 3, 5, 10),
    "WORLDINVADER": SongData(2900142, "61-5", "Ola Dash", True, 5, 8, 10),
    "N3V3R G3T OV3R": SongData(2900144, "60-0", "maimai DX Limited-time Suite", True, 4, 7, 10),
    "Oshama Scramble!": SongData(2900145, "60-1", "maimai DX Limited-time Suite", True, 5, 7, 10),
    "Valsqotch": SongData(2900146, "60-2", "maimai DX Limited-time Suite", True, 5, 9, 11),
    "Paranormal My Mind": SongData(2900147, "60-3", "maimai DX Limited-time Suite", True, 5, 7, 9),
    "Flower, snow and Drum'n'bass.": SongData(2900148, "60-4", "maimai DX Limited-time Suite", True, 5, 8, 10),
    "Amenohoakari": SongData(2900149, "60-5", "maimai DX Limited-time Suite", True, 6, 8, 10),
    "Boiling Blood": SongData(2900151, "59-0", "MSR Anthology", True, 5, 8, 10),
    "ManiFesto": SongData(2900152, "59-1", "MSR Anthology", True, 4, 6, 9),
    "Operation Blade": SongData(2900153, "59-2", "MSR Anthology", True, 3, 5, 7),
    "Radiant": SongData(2900154, "59-3", "MSR Anthology", True, 3, 5, 8),
    "Renegade": SongData(2900155, "59-4", "MSR Anthology", True, 3, 5, 8),
    "Speed of Light": SongData(2900156, "59-5", "MSR Anthology", False, 1, 4, 7),
    "Dossoles Holiday": SongData(2900157, "59-6", "MSR Anthology", True, 5, 7, 9),
    "Autumn Moods": SongData(2900158, "59-7", "MSR Anthology", True, 3, 5, 7),
    "People People": SongData(2900160, "58-0", "Nanahira Paradise", True, 5, 7, 9),
    "Endless Error Loop": SongData(2900161, "58-1", "Nanahira Paradise", True, 4, 7, 9),
    "Forbidden Pizza!": SongData(2900162, "58-2", "Nanahira Paradise", True, 5, 7, 9),
    "Don't Make the Vocalist do Anything Insane": SongData(2900163, "58-3", "Nanahira Paradise", True, 5, 8, 9),
    "Tokimeki*Meteostrike": SongData(2900165, "57-0", "Happy Otaku Pack Vol.16", True, 3, 6, 8),
    "Down Low": SongData(2900166, "57-1", "Happy Otaku Pack Vol.16", True, 4, 6, 8),
    "LOUDER MACHINE": SongData(2900167, "57-2", "Happy Otaku Pack Vol.16", True, 5, 7, 9),
    "Sorewa mo Lovechu": SongData(2900168, "57-3", "Happy Otaku Pack Vol.16", True, 5, 7, 10),
    "Rave_Tech": SongData(2900169, "57-4", "Happy Otaku Pack Vol.16", True, 5, 8, 10),
    "Brilliant & Shining!": SongData(2900170, "57-5", "Happy Otaku Pack Vol.16", False, 5, 8, 10),
    "Psyched Fevereiro": SongData(2900172, "56-0", "Give Up TREATMENT Vol.11", False, 5, 8, 10),
    "Inferno City": SongData(2900173, "56-1", "Give Up TREATMENT Vol.11", False, 6, 8, 10),
    "Paradigm Shift": SongData(2900174, "56-2", "Give Up TREATMENT Vol.11", False, 4, 7, 10),
    "Snapdragon": SongData(2900175, "56-3", "Give Up TREATMENT Vol.11", False, 5, 7, 10),
    "Prestige and Vestige": SongData(2900176, "56-4", "Give Up TREATMENT Vol.11", True, 6, 8, 11),
    "Tiny Fate": SongData(2900177, "56-5", "Give Up TREATMENT Vol.11", False, 7, 9, 11),
    "Tsuki ni Murakumo Hana ni Kaze": SongData(2900179, "55-0", "Touhou Mugakudan -II-", False, 3, 5, 7),
    "Patchouli's - Best Hit GSK": SongData(2900180, "55-1", "Touhou Mugakudan -II-", False, 3, 5, 8),
    "Monosugoi Space Shuttle de Koishi ga Monosugoi uta": SongData(2900181, "55-2", "Touhou Mugakudan -II-", False, 3, 5, 7),
    "Kakoinaki Yo wa Ichigo no Tsukikage": SongData(2900182, "55-3", "Touhou Mugakudan -II-", False, 3, 6, 8),
    "Psychedelic Kizakura Doumei": SongData(2900183, "55-4", "Touhou Mugakudan -II-", False, 4, 7, 10),
    "Mischievous Sensation": SongData(2900184, "55-5", "Touhou Mugakudan -II-", False, 5, 7, 9),
    "White Canvas": SongData(2900186, "54-0", "MEGAREX THE FUTURE", False, 3, 6, 8),
    "Gloomy Flash": SongData(2900187, "54-1", "MEGAREX THE FUTURE", False, 5, 8, 10),
    "Find this Month's Featured Playlist": SongData(2900188, "54-2", "MEGAREX THE FUTURE", False, 4, 7, 10),
    "Sunday Night": SongData(2900189, "54-3", "MEGAREX THE FUTURE", False, 3, 6, 9),
    "Goodbye Goodnight": SongData(2900190, "54-4", "MEGAREX THE FUTURE", False, 4, 6, 9),
    "ENDLESS CIDER": SongData(2900191, "54-5", "MEGAREX THE FUTURE", False, 4, 6, 8),
    "On And On!!": SongData(2900193, "53-0", "Happy Otaku Pack Vol.15", True, 4, 7, 9),
    "Trip!": SongData(2900194, "53-1", "Happy Otaku Pack Vol.15", True, 3, 5, 7),
    "Hoshi no otoshimono": SongData(2900195, "53-2", "Happy Otaku Pack Vol.15", False, 5, 7, 9),
    "Plucky Race": SongData(2900196, "53-3", "Happy Otaku Pack Vol.15", True, 5, 8, 10),
    "Fantasia Sonata Destiny": SongData(2900197, "53-4", "Happy Otaku Pack Vol.15", True, 3, 7, 10),
    "Run through": SongData(2900198, "53-5", "Happy Otaku Pack Vol.15", False, 5, 8, 10),
    "marooned night": SongData(2900200, "52-0", "MUSE RADIO FM103", False, 2, 4, 6),
    "daydream girl": SongData(2900201, "52-1", "MUSE RADIO FM103", False, 3, 6, 8),
    "Not Ornament": SongData(2900202, "52-2", "MUSE RADIO FM103", True, 3, 5, 8),
    "Baby Pink": SongData(2900203, "52-3", "MUSE RADIO FM103", False, 3, 5, 8),
    "I'm Here": SongData(2900204, "52-4", "MUSE RADIO FM103", False, 4, 6, 8),
    "Masquerade Diary": SongData(2900206, "51-0", "Virtual Idol Production", True, 2, 5, 8),
    "Reminiscence": SongData(2900207, "51-1", "Virtual Idol Production", True, 5, 7, 9),
    "DarakuDatenshi": SongData(2900208, "51-2", "Virtual Idol Production", True, 3, 6, 9),
    "D.I.Y.": SongData(2900209, "51-3", "Virtual Idol Production", False, 4, 6, 9),
    "Boys in Virtual Land": SongData(2900210, "51-4", "Virtual Idol Production", False, 4, 7, 9),
    "kui": SongData(2900211, "51-5", "Virtual Idol Production", True, 5, 7, 9),
    "Nyan Cat": SongData(2900213, "50-0", "Nyanya Universe!", False, 4, 7, 9),
    "PeroPero in the Universe": SongData(2900214, "50-1", "Nyanya Universe!", True, 4, 7, 10),
    "In-kya Yo-kya Onmyoji": SongData(2900215, "50-2", "Nyanya Universe!", False, 6, 8, 10),
    "KABOOOOOM!!!!": SongData(2900216, "50-3", "Nyanya Universe!", True, 4, 6, 8),
    "Doppelganger": SongData(2900217, "50-4", "Nyanya Universe!", True, 5, 7, 9),
    "Pray a LOVE": SongData(2900219, "49-0", "DokiDoki! Valentine!", False, 2, 5, 8),
    "Love-Avoidance Addiction": SongData(2900220, "49-1", "DokiDoki! Valentine!", False, 3, 5, 7),
    "Daisuki Dayo feat.Wotoha": SongData(2900221, "49-2", "DokiDoki! Valentine!", False, 5, 7, 10),
    "glory day": SongData(2900223, "48-0", "DJMAX Reflect", False, 2, 5, 7),
    "Bright Dream": SongData(2900224, "48-1", "DJMAX Reflect", False, 2, 4, 7),
    "Groovin Up": SongData(2900225, "48-2", "DJMAX Reflect", False, 4, 6, 8),
    "I Want You": SongData(2900226, "48-3", "DJMAX Reflect", False, 3, 6, 8),
    "OBLIVION": SongData(2900227, "48-4", "DJMAX Reflect", False, 3, 6, 9),
    "Elastic STAR": SongData(2900228, "48-5", "DJMAX Reflect", False, 4, 6, 8),
    "U.A.D": SongData(2900229, "48-6", "DJMAX Reflect", False, 4, 6, 8),
    "Jealousy": SongData(2900230, "48-7", "DJMAX Reflect", False, 3, 5, 7),
    "Memory of Beach": SongData(2900231, "48-8", "DJMAX Reflect", False, 3, 6, 8),
    "Don't Die": SongData(2900232, "48-9", "DJMAX Reflect", False, 6, 8, 10),
    "Y CE Ver.": SongData(2900233, "48-10", "DJMAX Reflect", False, 4, 6, 9),
    "Fancy Night": SongData(2900234, "48-11", "DJMAX Reflect", False, 4, 6, 8),
    "Can We Talk": SongData(2900235, "48-12", "DJMAX Reflect", False, 4, 6, 8),
    "Give Me 5": SongData(2900236, "48-13", "DJMAX Reflect", False, 2, 6, 8),
    "Nightmare": SongData(2900237, "48-14", "DJMAX Reflect", False, 7, 9, 11),
    "Haze of Autumn": SongData(2900239, "47-0", "Arcaea", True, 3, 6, 9),
    "GIMME DA BLOOD": SongData(2900240, "47-1", "Arcaea", False, 3, 6, 9),
    "Libertas": SongData(2900241, "47-2", "Arcaea", False, 4, 7, 10),
    "Cyaegha": SongData(2900242, "47-3", "Arcaea", False, 5, 7, 9),
    "Bang!!": SongData(2900244, "46-0", "Happy Otaku Pack Vol.14", False, 4, 6, 8),
    "Paradise 2": SongData(2900245, "46-1", "Happy Otaku Pack Vol.14", False, 4, 6, 8),
    "Symbol": SongData(2900246, "46-2", "Happy Otaku Pack Vol.14", False, 5, 7, 9),
    "Nekojarashi": SongData(2900247, "46-3", "Happy Otaku Pack Vol.14", False, 5, 8, 10),
    "A Philosophical Wanderer": SongData(2900248, "46-4", "Happy Otaku Pack Vol.14", False, 4, 6, 10),
    "Isouten": SongData(2900249, "46-5", "Happy Otaku Pack Vol.14", True, 6, 8, 10),
    "ONOMATO Pairing!!!": SongData(2900251, "45-0", "WACCA Horizon", False, 4, 6, 9),
    "with U": SongData(2900252, "45-1", "WACCA Horizon", False, 6, 8, 10),
    "Chariot": SongData(2900253, "45-2", "WACCA Horizon", False, 3, 6, 9),
    "GASHATT": SongData(2900254, "45-3", "WACCA Horizon", False, 5, 7, 10),
    "LIN NE KRO NE feat. lasah": SongData(2900255, "45-4", "WACCA Horizon", False, 6, 8, 10),
    "ANGEL HALO": SongData(2900256, "45-5", "WACCA Horizon", False, 5, 8, 11),
    "Party in the HOLLOWood": SongData(2900258, "44-0", "Happy Otaku Pack Vol.13", False, 3, 6, 8),
    "Ying Ying da Zuozhan": SongData(2900259, "44-1", "Happy Otaku Pack Vol.13", True, 5, 7, 9),
    "Howlin' Pumpkin": SongData(2900260, "44-2", "Happy Otaku Pack Vol.13", True, 4, 6, 8),
    "Bad Apple!! feat. Nomico": SongData(2900262, "42-0", "Touhou Mugakudan -I-", False, 1, 3, 6),
    "Iro wa Nioedo, Chirinuru wo": SongData(2900263, "42-1", "Touhou Mugakudan -I-", False, 2, 4, 7),
    "Cirno's Perfect Math Class": SongData(2900264, "42-2", "Touhou Mugakudan -I-", False, 4, 7, 9),
    "Hiiro Gekka Kyousai no Zetsu": SongData(2900265, "42-3", "Touhou Mugakudan -I-", False, 4, 6, 8),
    "Flowery Moonlit Night": SongData(2900266, "42-4", "Touhou Mugakudan -I-", False, 3, 6, 8),
    "Unconscious Requiem": SongData(2900267, "42-5", "Touhou Mugakudan -I-", False, 3, 6, 8),
    "Super Battleworn Insomniac": SongData(2900269, "41-0", "7th Beat Games", True, 4, 7, 9),
    "Bomb-Sniffing Pomeranian": SongData(2900270, "41-1", "7th Beat Games", True, 4, 6, 8),
    "Rollerdisco Rumble": SongData(2900271, "41-2", "7th Beat Games", True, 4, 6, 9),
    "Rose Garden": SongData(2900272, "41-3", "7th Beat Games", False, 5, 8, 9),
    "EMOMOMO": SongData(2900273, "41-4", "7th Beat Games", True, 4, 7, 10),
    "Heracles": SongData(2900274, "41-5", "7th Beat Games", False, 6, 8, 10),
    "Rush-More": SongData(2900276, "40-0", "Happy Otaku Pack Vol.12", False, 4, 7, 9),
    "Kill My Fortune": SongData(2900277, "40-1", "Happy Otaku Pack Vol.12", False, 5, 7, 10),
    "Yosari Tsukibotaru Suminoborite": SongData(2900278, "40-2", "Happy Otaku Pack Vol.12", False, 5, 7, 9),
    "JUMP! HardCandy": SongData(2900279, "40-3", "Happy Otaku Pack Vol.12", False, 3, 6, 8),
    "Hibari": SongData(2900280, "40-4", "Happy Otaku Pack Vol.12", False, 3, 5, 8),
    "OCCHOCO-REST-LESS": SongData(2900281, "40-5", "Happy Otaku Pack Vol.12", True, 4, 7, 9),
    "See-Saw Day": SongData(2900283, "39-0", "MUSE RADIO FM102", True, 1, 3, 6),
    "happy hour": SongData(2900284, "39-1", "MUSE RADIO FM102", True, 2, 4, 7),
    "Seikimatsu no Natsu": SongData(2900285, "39-2", "MUSE RADIO FM102", True, 4, 6, 8),
    "twinkle night": SongData(2900286, "39-3", "MUSE RADIO FM102", False, 3, 6, 8),
    "ARUYA HARERUYA": SongData(2900287, "39-4", "MUSE RADIO FM102", False, 2, 5, 7),
    "Blush": SongData(2900288, "39-5", "MUSE RADIO FM102", False, 2, 4, 7),
    "Naked Summer": SongData(2900289, "39-6", "MUSE RADIO FM102", True, 4, 6, 8),
    "BLESS ME": SongData(2900290, "39-7", "MUSE RADIO FM102", True, 2, 5, 7),
    "FM 17314 SUGAR RADIO": SongData(2900291, "39-8", "MUSE RADIO FM102", True, None, None, None),
    "NO ONE YES MAN": SongData(2900293, "38-0", "Phigros", False, 5, 7, 9),
    "Snowfall, Merry Christmas": SongData(2900294, "38-1", "Phigros", False, 5, 8, 10),
    "Igallta": SongData(2900295, "38-2", "Phigros", False, 6, 8, 10),
    "Colored Glass": SongData(2900297, "37-0", "Cute Is Everything Vol.7", False, 1, 4, 7),
    "Neonlights": SongData(2900298, "37-1", "Cute Is Everything Vol.7", False, 4, 7, 9),
    "Hope for the flowers": SongData(2900299, "37-2", "Cute Is Everything Vol.7", False, 4, 7, 9),
    "Seaside Cycling on May 30": SongData(2900300, "37-3", "Cute Is Everything Vol.7", False, 3, 6, 8),
    "SKY HIGH": SongData(2900301, "37-4", "Cute Is Everything Vol.7", False, 2, 4, 6),
    "Mousou Chu!!": SongData(2900302, "37-5", "Cute Is Everything Vol.7", False, 4, 7, 8),
    "NightTheater": SongData(2900304, "36-0", "Give Up TREATMENT Vol.10", True, 6, 8, 11),
    "Cutter": SongData(2900305, "36-1", "Give Up TREATMENT Vol.10", False, 4, 7, 10),
    "bamboo": SongData(2900306, "36-2", "Give Up TREATMENT Vol.10", False, 6, 8, 10),
    "enchanted love": SongData(2900307, "36-3", "Give Up TREATMENT Vol.10", False, 2, 6, 9),
    "c.s.q.n.": SongData(2900308, "36-4", "Give Up TREATMENT Vol.10", False, 5, 8, 11),
    "Booouncing!!": SongData(2900309, "36-5", "Give Up TREATMENT Vol.10", False, 5, 7, 10),
    "PeroPeroGames goes Bankrupt": SongData(2900311, "35-0", "Happy Otaku Pack SP", True, 6, 8, 10),
    "MARENOL": SongData(2900312, "35-1", "Happy Otaku Pack SP", False, 4, 7, 10),
    "I am really good at Japanese style": SongData(2900313, "35-2", "Happy Otaku Pack SP", True, 6, 8, 10),
    "Rush B": SongData(2900314, "35-3", "Happy Otaku Pack SP", True, 4, 7, 9),
    "DataErr0r": SongData(2900315, "35-4", "Happy Otaku Pack SP", False, 5, 7, 9),
    "Burn": SongData(2900316, "35-5", "Happy Otaku Pack SP", True, 4, 7, 9),
    "ALiVE": SongData(2900318, "34-0", "HARDCORE TANO*C", False, 5, 7, 10),
    "BATTLE NO.1": SongData(2900319, "34-1", "HARDCORE TANO*C", False, 5, 8, 10),
    "Cthugha": SongData(2900320, "34-2", "HARDCORE TANO*C", False, 6, 8, 10),
    "TWINKLE*MAGIC": SongData(2900321, "34-3", "HARDCORE TANO*C", False, 4, 7, 10),
    "Comet Coaster": SongData(2900322, "34-4", "HARDCORE TANO*C", False, 6, 8, 10),
    "XODUS": SongData(2900323, "34-5", "HARDCORE TANO*C", False, 7, 9, 11),
    "Fireflies": SongData(2900325, "33-0", "cyTus", True, 1, 4, 7),
    "Light up my love!!": SongData(2900326, "33-1", "cyTus", True, 3, 5, 7),
    "Happiness Breeze": SongData(2900327, "33-2", "cyTus", True, 4, 6, 8),
    "Chrome VOX": SongData(2900328, "33-3", "cyTus", True, 6, 8, 10),
    "CHAOS": SongData(2900329, "33-4", "cyTus", True, 3, 6, 9),
    "Saika": SongData(2900330, "33-5", "cyTus", True, 3, 5, 8),
    "Standby for Action": SongData(2900331, "33-6", "cyTus", True, 4, 6, 8),
    "Hydrangea": SongData(2900332, "33-7", "cyTus", True, 5, 7, 9),
    "Amenemhat": SongData(2900333, "33-8", "cyTus", True, 6, 8, 10),
    "Santouka": SongData(2900334, "33-9", "cyTus", True, 2, 5, 8),
    "HEXENNACHTROCK-katashihaya-": SongData(2900335, "33-10", "cyTus", True, 4, 8, 10),
    "Blah!!": SongData(2900336, "33-11", "cyTus", True, 5, 8, 11),
    "CHAOS Glitch": SongData(2900337, "33-12", "cyTus", True, None, None, None),
    "Preparara": SongData(2900339, "32-0", "Let's Do Bad Things Together", False, 1, 4, 6),
    "Whatcha;Whatcha Doin'": SongData(2900340, "32-1", "Let's Do Bad Things Together", False, 3, 6, 9),
    "Madara": SongData(2900341, "32-2", "Let's Do Bad Things Together", False, 4, 6, 9),
    "pICARESq": SongData(2900342, "32-3", "Let's Do Bad Things Together", False, 4, 6, 8),
    "Desastre": SongData(2900343, "32-4", "Let's Do Bad Things Together", False, 4, 6, 8),
    "Shoot for the Moon": SongData(2900344, "32-5", "Let's Do Bad Things Together", False, 2, 5, 8),
    "The 90's Decision": SongData(2900346, "31-0", "Happy Otaku Pack Vol.11", True, 5, 7, 9),
    "Medusa": SongData(2900347, "31-1", "Happy Otaku Pack Vol.11", False, 4, 6, 8),
    "Final Step!": SongData(2900348, "31-2", "Happy Otaku Pack Vol.11", False, 5, 7, 10),
    "MAGENTA POTION": SongData(2900349, "31-3", "Happy Otaku Pack Vol.11", False, 4, 7, 9),
    "Cross Ray": SongData(2900350, "31-4", "Happy Otaku Pack Vol.11", False, 3, 6, 9),
    "Square Lake": SongData(2900351, "31-5", "Happy Otaku Pack Vol.11", False, 6, 8, 9),
    "Girly Cupid": SongData(2900353, "30-0", "Cute Is Everything Vol.6", False, 3, 6, 8),
    "sheep in the light": SongData(2900354, "30-1", "Cute Is Everything Vol.6", False, 2, 5, 8),
    "Breaker city": SongData(2900355, "30-2", "Cute Is Everything Vol.6", False, 4, 6, 9),
    "heterodoxy": SongData(2900356, "30-3", "Cute Is Everything Vol.6", False, 4, 6, 8),
    "Computer Music Girl": SongData(2900357, "30-4", "Cute Is Everything Vol.6", False, 3, 5, 7),
    "Focus Point": SongData(2900358, "30-5", "Cute Is Everything Vol.6", True, 2, 5, 7),
    "Groove Prayer": SongData(2900360, "29-0", "Let' s GROOVE!", True, 3, 5, 7),
    "FUJIN Rumble": SongData(2900361, "29-1", "Let' s GROOVE!", True, 5, 7, 10),
    "Marry me, Nightmare": SongData(2900362, "29-2", "Let' s GROOVE!", False, 6, 8, 11),
    "HG Makaizou Polyvinyl Shounen": SongData(2900363, "29-3", "Let' s GROOVE!", True, 4, 7, 9),
    "Seizya no Ibuki": SongData(2900364, "29-4", "Let' s GROOVE!", True, 6, 8, 10),
    "ouroboros -twin stroke of the end-": SongData(2900365, "29-5", "Let' s GROOVE!", True, 4, 6, 9),
    "Heisha Onsha": SongData(2900367, "28-0", "Happy Otaku Pack Vol.10", False, 4, 6, 8),
    "Ginevra": SongData(2900368, "28-1", "Happy Otaku Pack Vol.10", True, 5, 7, 10),
    "Paracelestia": SongData(2900369, "28-2", "Happy Otaku Pack Vol.10", False, 5, 8, 10),
    "un secret": SongData(2900370, "28-3", "Happy Otaku Pack Vol.10", False, 2, 4, 6),
    "Good Life": SongData(2900371, "28-4", "Happy Otaku Pack Vol.10", False, 4, 6, 8),
    "nini-nini-": SongData(2900372, "28-5", "Happy Otaku Pack Vol.10", False, 4, 7, 9),
    "Can I friend you on Bassbook? lol": SongData(2900374, "27-0", "Nanahira Festival", False, 3, 6, 8),
    "Gaming*Everything": SongData(2900375, "27-1", "Nanahira Festival", False, 5, 8, 11),
    "Renji de haochi": SongData(2900376, "27-2", "Nanahira Festival", False, 5, 7, 9),
    "You Make My Life 1UP": SongData(2900377, "27-3", "Nanahira Festival", False, 4, 6, 8),
    "Newbies, Geeks, Internets": SongData(2900378, "27-4", "Nanahira Festival", False, 6, 8, 10),
    "Onegai!Kon kon Oinarisama": SongData(2900379, "27-5", "Nanahira Festival", False, 3, 6, 9),
    "Legend of Eastern Rabbit -SKY DEFENDER-": SongData(2900381, "26-0", "Give Up TREATMENT Vol.9", False, 4, 6, 9),
    "ENERGY SYNERGY MATRIX": SongData(2900382, "26-1", "Give Up TREATMENT Vol.9", False, 6, 8, 10),
    "Punai Punai Genso": SongData(2900383, "26-2", "Give Up TREATMENT Vol.9", False, 2, 7, 11),
    "Better Graphic Animation": SongData(2900384, "26-3", "Give Up TREATMENT Vol.9", False, 5, 8, 11),
    "Variant Cross": SongData(2900385, "26-4", "Give Up TREATMENT Vol.9", False, 4, 7, 10),
    "Ultra Happy Miracle Bazoooooka!!": SongData(2900386, "26-5", "Give Up TREATMENT Vol.9", False, 7, 9, 11),
    "tape/stop/night": SongData(2900388, "25-0", "MUSE RADIO FM101", True, 3, 5, 7),
    "Pixel Galaxy": SongData(2900389, "25-1", "MUSE RADIO FM101", False, 2, 5, 8),
    "Notice": SongData(2900390, "25-2", "MUSE RADIO FM101", False, 4, 7, 10),
    "Strawberry Godzilla": SongData(2900391, "25-3", "MUSE RADIO FM101", True, 2, 5, 7),
    "OKIMOCHI EXPRESSION": SongData(2900392, "25-4", "MUSE RADIO FM101", False, 4, 6, 10),
    "Kimi to pool disco": SongData(2900393, "25-5", "MUSE RADIO FM101", False, 4, 6, 8),
    "The Last Page": SongData(2900395, "24-0", "Happy Otaku Pack Vol.9", False, 3, 5, 7),
    "IKAROS": SongData(2900396, "24-1", "Happy Otaku Pack Vol.9", False, 4, 7, 10),
    "Tsukuyomi": SongData(2900397, "24-2", "Happy Otaku Pack Vol.9", False, 3, 6, 9),
    "Future Stream": SongData(2900398, "24-3", "Happy Otaku Pack Vol.9", False, 4, 6, 8),
    "FULi AUTO SHOOTER": SongData(2900399, "24-4", "Happy Otaku Pack Vol.9", True, 4, 7, 9),
    "GOODFORTUNE": SongData(2900400, "24-5", "Happy Otaku Pack Vol.9", False, 5, 7, 9),
    "The Dessert After Rain": SongData(2900402, "23-0", "Cute Is Everything Vol.5", True, 2, 4, 6),
    "Confession Support Formula": SongData(2900403, "23-1", "Cute Is Everything Vol.5", False, 3, 5, 7),
    "Omatsuri": SongData(2900404, "23-2", "Cute Is Everything Vol.5", False, 1, 3, 6),
    "FUTUREPOP": SongData(2900405, "23-3", "Cute Is Everything Vol.5", True, 2, 5, 7),
    "The Breeze": SongData(2900406, "23-4", "Cute Is Everything Vol.5", False, 1, 4, 6),
    "I LOVE LETTUCE FRIED RICE!!": SongData(2900407, "23-5", "Cute Is Everything Vol.5", False, 3, 7, 9),
    "The NightScape": SongData(2900409, "22-0", "Give Up TREATMENT Vol.8", False, 4, 7, 9),
    "FREEDOM DiVE": SongData(2900410, "22-1", "Give Up TREATMENT Vol.8", False, 6, 8, 10),
    "Phi": SongData(2900411, "22-2", "Give Up TREATMENT Vol.8", False, 5, 8, 10),
    "Lueur de la nuit": SongData(2900412, "22-3", "Give Up TREATMENT Vol.8", False, 6, 8, 11),
    "Creamy Sugary OVERDRIVE!!!": SongData(2900413, "22-4", "Give Up TREATMENT Vol.8", True, 4, 7, 10),
    "Disorder": SongData(2900414, "22-5", "Give Up TREATMENT Vol.8", False, 5, 7, 11),
    "Glimmer": SongData(2900416, "21-0", "Budget Is Burning: Nano Core", False, 2, 5, 8),
    "EXIST": SongData(2900417, "21-1", "Budget Is Burning: Nano Core", False, 3, 5, 8),
    "Irreplaceable": SongData(2900418, "21-2", "Budget Is Burning: Nano Core", False, 4, 6, 8),
    "Moonlight Banquet": SongData(2900420, "20-0", "Happy Otaku Pack Vol.8", True, 2, 5, 8),
    "Flashdance": SongData(2900421, "20-1", "Happy Otaku Pack Vol.8", False, 3, 6, 9),
    "INFiNiTE ENERZY -Overdoze-": SongData(2900422, "20-2", "Happy Otaku Pack Vol.8", False, 4, 7, 9),
    "One Way Street": SongData(2900423, "20-3", "Happy Otaku Pack Vol.8", False, 3, 6, 10),
    "This Club is Not 4 U": SongData(2900424, "20-4", "Happy Otaku Pack Vol.8", False, 4, 7, 9),
    "ULTRA MEGA HAPPY PARTY!!!": SongData(2900425, "20-5", "Happy Otaku Pack Vol.8", False, 5, 7, 10),
    "INFINITY": SongData(2900427, "19-0", "Give Up TREATMENT Vol.7", True, 5, 8, 10),
    "Punai Punai Senso": SongData(2900428, "19-1", "Give Up TREATMENT Vol.7", False, 2, 7, 11),
    "Maxi": SongData(2900429, "19-2", "Give Up TREATMENT Vol.7", False, 5, 8, 10),
    "YInMn Blue": SongData(2900430, "19-3", "Give Up TREATMENT Vol.7", False, 6, 8, 10),
    "Plumage": SongData(2900431, "19-4", "Give Up TREATMENT Vol.7", False, 4, 7, 10),
    "Dr.Techro": SongData(2900432, "19-5", "Give Up TREATMENT Vol.7", False, 7, 9, 11),
    "SWEETSWEETSWEET": SongData(2900434, "18-0", "Cute Is Everything Vol.4", True, 2, 5, 7),
    "Deep Blue and the Breaths of the Night": SongData(2900435, "18-1", "Cute Is Everything Vol.4", True, 2, 4, 6),
    "Joy Connection": SongData(2900436, "18-2", "Cute Is Everything Vol.4", False, 3, 6, 8),
    "Self Willed Girl Ver.B": SongData(2900437, "18-3", "Cute Is Everything Vol.4", True, 4, 6, 8),
    "Just Disobedient": SongData(2900438, "18-4", "Cute Is Everything Vol.4", False, 3, 6, 8),
    "Holy Sh*t Grass Snake": SongData(2900439, "18-5", "Cute Is Everything Vol.4", False, 2, 6, 9),
    "Cotton Candy Wonderland": SongData(2900441, "17-0", "Happy Otaku Pack Vol.7", False, 2, 5, 8),
    "Punai Punai Taiso": SongData(2900442, "17-1", "Happy Otaku Pack Vol.7", False, 2, 7, 10),
    "Fly High": SongData(2900443, "17-2", "Happy Otaku Pack Vol.7", False, 3, 5, 7),
    "prejudice": SongData(2900444, "17-3", "Happy Otaku Pack Vol.7", True, 4, 6, 9),
    "The 89's Momentum": SongData(2900445, "17-4", "Happy Otaku Pack Vol.7", True, 5, 7, 9),
    "energy night": SongData(2900446, "17-5", "Happy Otaku Pack Vol.7", True, 5, 7, 10),
    "Future Dive": SongData(2900448, "16-0", "Give Up TREATMENT Vol.6", True, 4, 6, 9),
    "Re End of a Dream": SongData(2900449, "16-1", "Give Up TREATMENT Vol.6", False, 5, 8, 11),
    "Etude -Storm-": SongData(2900450, "16-2", "Give Up TREATMENT Vol.6", True, 6, 8, 10),
    "Unlimited Katharsis": SongData(2900451, "16-3", "Give Up TREATMENT Vol.6", False, 4, 6, 10),
    "Magic Knight Girl": SongData(2900452, "16-4", "Give Up TREATMENT Vol.6", False, 4, 7, 9),
    "Eeliaas": SongData(2900453, "16-5", "Give Up TREATMENT Vol.6", False, 6, 9, 11),
    "Magic Spell": SongData(2900455, "15-0", "Cute Is Everything Vol.3", True, 2, 5, 7),
    "Colorful Star, Colored Drawing, Travel Poem": SongData(2900456, "15-1", "Cute Is Everything Vol.3", False, 3, 4, 6),
    "Satell Knight": SongData(2900457, "15-2", "Cute Is Everything Vol.3", False, 3, 6, 8),
    "Black River Feat.Mes": SongData(2900458, "15-3", "Cute Is Everything Vol.3", True, 1, 4, 6),
    "I am sorry": SongData(2900459, "15-4", "Cute Is Everything Vol.3", False, 2, 5, 8),
    "Ueta Tori Tachi": SongData(2900460, "15-5", "Cute Is Everything Vol.3", False, 3, 6, 8),
    "Elysion's Old Mans": SongData(2900462, "14-0", "Happy Otaku Pack Vol.6", False, 3, 5, 8),
    "AXION": SongData(2900463, "14-1", "Happy Otaku Pack Vol.6", False, 4, 5, 8),
    "Amnesia": SongData(2900464, "14-2", "Happy Otaku Pack Vol.6", True, 3, 6, 9),
    "Onsen Dai Sakusen": SongData(2900465, "14-3", "Happy Otaku Pack Vol.6", True, 4, 6, 8),
    "Gleam stone": SongData(2900466, "14-4", "Happy Otaku Pack Vol.6", False, 4, 7, 9),
    "GOODWORLD": SongData(2900467, "14-5", "Happy Otaku Pack Vol.6", False, 4, 7, 10),
    "Instant Soluble Neon": SongData(2900469, "13-0", "Cute Is Everything Vol.2", True, 2, 4, 7),
    "Retrospective Poem on the Planet": SongData(2900470, "13-1", "Cute Is Everything Vol.2", False, 3, 5, 7),
    "I'm Gonna Buy! Buy! Buy!": SongData(2900471, "13-2", "Cute Is Everything Vol.2", True, 4, 6, 8),
    "Dating Manifesto": SongData(2900472, "13-3", "Cute Is Everything Vol.2", True, 2, 4, 6),
    "First Snow": SongData(2900473, "13-4", "Cute Is Everything Vol.2", True, 2, 3, 6),
    "Xin Shang Huahai": SongData(2900474, "13-5", "Cute Is Everything Vol.2", False, 3, 6, 8),
    "Gaikan Chrysalis": SongData(2900476, "12-0", "Give Up TREATMENT Vol.5", False, 4, 6, 8),
    "Sterelogue": SongData(2900477, "12-1", "Give Up TREATMENT Vol.5", True, 5, 7, 10),
    "Cheshire's Dance": SongData(2900478, "12-2", "Give Up TREATMENT Vol.5", True, 4, 7, 10),
    "Skrik": SongData(2900479, "12-3", "Give Up TREATMENT Vol.5", True, 5, 7, 11),
    "Soda Pop Canva5!": SongData(2900480, "12-4", "Give Up TREATMENT Vol.5", False, 5, 8, 10),
    "RUBY LINTe": SongData(2900481, "12-5", "Give Up TREATMENT Vol.5", False, 5, 8, 11),
    "Brave My Heart": SongData(2900483, "11-0", "Happy Otaku Pack Vol.5", True, 3, 5, 7),
    "Sakura Fubuki": SongData(2900484, "11-1", "Happy Otaku Pack Vol.5", False, 4, 7, 10),
    "8bit Adventurer": SongData(2900485, "11-2", "Happy Otaku Pack Vol.5", False, 6, 8, 10),
    "Suffering of screw": SongData(2900486, "11-3", "Happy Otaku Pack Vol.5", False, 3, 5, 8),
    "tiny lady": SongData(2900487, "11-4", "Happy Otaku Pack Vol.5", True, 4, 6, 9),
    "Power Attack": SongData(2900488, "11-5", "Happy Otaku Pack Vol.5", False, 5, 7, 10),
    "Destr0yer": SongData(2900490, "10-0", "Give Up TREATMENT Vol.4", False, 4, 7, 9),
    "Noel": SongData(2900491, "10-1", "Give Up TREATMENT Vol.4", False, 5, 8, 10),
    "Kyoukiranbu": SongData(2900492, "10-2", "Give Up TREATMENT Vol.4", False, 7, 9, 11),
    "Two Phace": SongData(2900493, "10-3", "Give Up TREATMENT Vol.4", True, 4, 7, 10),
    "Fly Again": SongData(2900494, "10-4", "Give Up TREATMENT Vol.4", False, 5, 7, 10),
    "ouroVoros": SongData(2900495, "10-5", "Give Up TREATMENT Vol.4", False, 7, 9, 11),
    "Leave It Alone": SongData(2900497, "9-0", "Happy Otaku Pack Vol.4", True, 2, 5, 8),
    "Tsubasa no Oreta Tenshitachi no Requiem": SongData(2900498, "9-1", "Happy Otaku Pack Vol.4", False, 4, 7, 9),
    "Chronomia": SongData(2900499, "9-2", "Happy Otaku Pack Vol.4", False, 5, 7, 10),
    "Dandelion's Daydream": SongData(2900500, "9-3", "Happy Otaku Pack Vol.4", True, 5, 7, 8),
    "Lorikeet Flat design": SongData(2900501, "9-4", "Happy Otaku Pack Vol.4", True, 5, 7, 10),
    "GOODRAGE": SongData(2900502, "9-5", "Happy Otaku Pack Vol.4", False, 6, 9, 11),
    "Altale": SongData(2900504, "8-0", "Give Up TREATMENT Vol.3", False, 3, 5, 7),
    "Brain Power": SongData(2900505, "8-1", "Give Up TREATMENT Vol.3", False, 4, 7, 10),
    "Berry Go!!": SongData(2900506, "8-2", "Give Up TREATMENT Vol.3", False, 3, 6, 9),
    "Sweet* Witch* Girl*": SongData(2900507, "8-3", "Give Up TREATMENT Vol.3", False, 6, 8, 10),
    "trippers feeling!": SongData(2900508, "8-4", "Give Up TREATMENT Vol.3", True, 5, 7, 9),
    "Lilith ambivalence lovers": SongData(2900509, "8-5", "Give Up TREATMENT Vol.3", False, 5, 8, 10),
    "Brave My Soul": SongData(2900511, "7-0", "Give Up TREATMENT Vol.2", False, 4, 6, 8),
    "Halcyon": SongData(2900512, "7-1", "Give Up TREATMENT Vol.2", False, 4, 7, 10),
    "Crimson Nightingale": SongData(2900513, "7-2", "Give Up TREATMENT Vol.2", True, 4, 7, 10),
    "Invader": SongData(2900514, "7-3", "Give Up TREATMENT Vol.2", True, 3, 7, 11),
    "Lyrith": SongData(2900515, "7-4", "Give Up TREATMENT Vol.2", False, 5, 7, 10),
    "GOODBOUNCE": SongData(2900516, "7-5", "Give Up TREATMENT Vol.2", False, 4, 6, 9),
    "Out of Sense": SongData(2900518, "6-0", "Budget Is Burning Vol.1", False, 3, 5, 8),
    "My Life Is For You": SongData(2900519, "6-1", "Budget Is Burning Vol.1", False, 2, 4, 7),
    "Etude -Sunset-": SongData(2900520, "6-2", "Budget Is Burning Vol.1", True, 5, 7, 9),
    "Goodbye Boss": SongData(2900521, "6-3", "Budget Is Burning Vol.1", False, 4, 6, 8),
    "Stargazer": SongData(2900522, "6-4", "Budget Is Burning Vol.1", True, 2, 5, 8),
    "Lys Tourbillon": SongData(2900523, "6-5", "Budget Is Burning Vol.1", True, 4, 6, 8),
    "Thirty Million Persona": SongData(2900525, "5-0", "Happy Otaku Pack Vol.3", False, 2, 4, 6),
    "conflict": SongData(2900526, "5-1", "Happy Otaku Pack Vol.3", False, 2, 6, 9),
    "Enka Dance Music": SongData(2900527, "5-2", "Happy Otaku Pack Vol.3", False, 3, 5, 7),
    "XING": SongData(2900528, "5-3", "Happy Otaku Pack Vol.3", True, 4, 6, 8),
    "Amakakeru Soukyuu no Serenade": SongData(2900529, "5-4", "Happy Otaku Pack Vol.3", False, 3, 6, 9),
    "Gift box": SongData(2900530, "5-5", "Happy Otaku Pack Vol.3", False, 5, 7, 10),
    "MUSEDASH!!!!": SongData(2900532, "4-0", "Happy Otaku Pack Vol.2", False, 2, 6, 9),
    "Imprinting": SongData(2900533, "4-1", "Happy Otaku Pack Vol.2", False, 3, 6, 9),
    "Skyward": SongData(2900534, "4-2", "Happy Otaku Pack Vol.2", True, 4, 7, 10),
    "La nuit de vif": SongData(2900535, "4-3", "Happy Otaku Pack Vol.2", True, 2, 5, 8),
    "Bit-alize": SongData(2900536, "4-4", "Happy Otaku Pack Vol.2", False, 3, 6, 8),
    "GOODTEK": SongData(2900537, "4-5", "Happy Otaku Pack Vol.2", False, 4, 6, 9),
    "Maharajah": SongData(2900539, "3-0", "Happy Otaku Pack Vol.1", False, 1, 3, 6),
    "keep on running": SongData(2900540, "3-1", "Happy Otaku Pack Vol.1", False, 5, 7, 9),
    "Kafig": SongData(2900541, "3-2", "Happy Otaku Pack Vol.1", True, 4, 6, 8),
    "-+": SongData(2900542, "3-3", "Happy Otaku Pack Vol.1", True, 4, 6, 8),
    "Tenri Kaku Jou": SongData(2900543, "3-4", "Happy Otaku Pack Vol.1", True, 3, 6, 9),
    "Adjudicatorz-DanZai-": SongData(2900544, "3-5", "Happy Otaku Pack Vol.1", False, 3, 7, 10),
    "Oriens": SongData(2900546, "2-0", "Give Up TREATMENT Vol.1", True, 3, 7, 9),
    "PUPA": SongData(2900547, "2-1", "Give Up TREATMENT Vol.1", False, 6, 8, 11),
    "Luna Express 2032": SongData(2900548, "2-2", "Give Up TREATMENT Vol.1", False, 4, 6, 8),
    "Ukiyoe Yokochou": SongData(2900549, "2-3", "Give Up TREATMENT Vol.1", False, 6, 7, 9),
    "Alice in Misanthrope": SongData(2900550, "2-4", "Give Up TREATMENT Vol.1", False, 5, 7, 10),
    "GOODMEN": SongData(2900551, "2-5", "Give Up TREATMENT Vol.1", False, 5, 7, 10),
    "Sunshine and Rainbow after August Rain": SongData(2900553, "1-0", "Cute Is Everything Vol.1", False, 2, 5, 8),
    "Magical Number": SongData(2900554, "1-1", "Cute Is Everything Vol.1", False, 2, 5, 8),
    "Dreaming Girl": SongData(2900555, "1-2", "Cute Is Everything Vol.1", False, 2, 5, 6),
    "Daruma-san Fell Over": SongData(2900556, "1-3", "Cute Is Everything Vol.1", False, 3, 4, 6),
    "Different": SongData(2900557, "1-4", "Cute Is Everything Vol.1", False, 1, 3, 6),
    "The Future of the Phantom": SongData(2900558, "1-5", "Cute Is Everything Vol.1", False, 1, 3, 5),
    "Doki Doki Jump!": SongData(2900560, "63-0", "MUSE RADIO FM104", True, 3, 5, 7),
    "Centennial Streamers High": SongData(2900561, "63-1", "MUSE RADIO FM104", False, 4, 7, 9),
    "Love Patrol": SongData(2900562, "63-2", "MUSE RADIO FM104", True, 3, 5, 7),
    "Mahorova": SongData(2900563, "63-3", "MUSE RADIO FM104", True, 3, 5, 8),
    "Yoru no machi": SongData(2900564, "63-4", "MUSE RADIO FM104", True, 1, 4, 7),
    "INTERNET YAMERO": SongData(2900565, "63-5", "MUSE RADIO FM104", True, 6, 8, 10),
    "Abracadabra": SongData(2900566, "43-24", "MD Plus Project", False, 6, 8, 10),
    "Squalldecimator feat. EZ-Ven": SongData(2900567, "43-25", "MD Plus Project", True, 5, 7, 9),
    "Amateras Rhythm": SongData(2900568, "43-26", "MD Plus Project", True, 6, 8, 11),
    "Record one's Dream": SongData(2900569, "43-27", "MD Plus Project", False, 4, 7, 10),
    "Lunatic": SongData(2900570, "43-28", "MD Plus Project", True, 5, 8, 10),
    "Jiumeng": SongData(2900571, "43-29", "MD Plus Project", True, 3, 6, 8),
    "The Day We Become Family": SongData(2900572, "43-30", "MD Plus Project", True, 3, 5, 8),
    "Sutori ma FIRE!?!?": SongData(2900574, "64-0", "COSMIC RADIO PEROLIST", True, 3, 5, 8),
    "Tanuki Step": SongData(2900575, "64-1", "COSMIC RADIO PEROLIST", True, 5, 7, 10),
    "Space Stationery": SongData(2900576, "64-2", "COSMIC RADIO PEROLIST", True, 5, 7, 10),
    "Songs Are Judged 90% by Chorus feat. Mameko": SongData(2900577, "64-3", "COSMIC RADIO PEROLIST", True, 6, 8, 10),
    "Kawai Splendid Space Thief": SongData(2900578, "64-4", "COSMIC RADIO PEROLIST", False, 6, 8, 10),
    "Night City Runway": SongData(2900579, "64-5", "COSMIC RADIO PEROLIST", True, 4, 6, 8),
    "Chaos Shotgun feat. ChumuNote": SongData(2900580, "64-6", "COSMIC RADIO PEROLIST", True, 6, 8, 10),
    "mew mew magical summer": SongData(2900581, "64-7", "COSMIC RADIO PEROLIST", False, 5, 8, 10),
    "BrainDance": SongData(2900583, "65-0", "NeonAbyss", True, 3, 6, 9),
    "My Focus!": SongData(2900584, "65-1", "NeonAbyss", True, 5, 7, 10),
    "ABABABA BURST": SongData(2900585, "65-2", "NeonAbyss", True, 5, 7, 9),
    "ULTRA HIGHER": SongData(2900586, "65-3", "NeonAbyss", True, 4, 7, 10),
    "Silver Bullet": SongData(2900587, "43-31", "MD Plus Project", True, 5, 7, 10),
    "Random": SongData(2900588, "43-32", "MD Plus Project", True, 4, 7, 9),
    "OTOGE-BOSS-KYOKU-CHAN": SongData(2900589, "43-33", "MD Plus Project", False, 6, 8, 10),
    "Crow Rabbit": SongData(2900590, "43-34", "MD Plus Project", True, 7, 9, 11),
    "SyZyGy": SongData(2900591, "43-35", "MD Plus Project", True, 6, 8, 10),
    "Mermaid Radio": SongData(2900592, "43-36", "MD Plus Project", True, 3, 5, 7),
    "Helixir": SongData(2900593, "43-37", "MD Plus Project", False, 6, 8, 10),
    "Highway Cruisin'": SongData(2900594, "43-38", "MD Plus Project", False, 3, 5, 8),
    "JACK PT BOSS": SongData(2900595, "43-39", "MD Plus Project", False, 6, 8, 10),
    "Time Capsule": SongData(2900596, "43-40", "MD Plus Project", False, 7, 9, 11),
    "39 Music!": SongData(2900598, "66-0", "Miku in Museland", False, 3, 5, 8),
    "Hand in Hand": SongData(2900599, "66-1", "Miku in Museland", False, 1, 3, 6),
    "Cynical Night Plan": SongData(2900600, "66-2", "Miku in Museland", False, 4, 6, 8),
    "God-ish": SongData(2900601, "66-3", "Miku in Museland", False, 4, 7, 10),
    "Darling Dance": SongData(2900602, "66-4", "Miku in Museland", False, 4, 7, 9),
    "Hatsune Creation Myth": SongData(2900603, "66-5", "Miku in Museland", False, 6, 8, 10),
    "The Vampire": SongData(2900604, "66-6", "Miku in Museland", False, 4, 6, 9),
    "Future Eve": SongData(2900605, "66-7", "Miku in Museland", False, 4, 8, 11),
    "Unknown Mother Goose": SongData(2900606, "66-8", "Miku in Museland", False, 4, 8, 10),
    "Shun-ran": SongData(2900607, "66-9", "Miku in Museland", False, 4, 7, 9),
    "NICE TYPE feat. monii": SongData(2900608, "43-41", "MD Plus Project", True, 3, 6, 8),
    "Rainy Angel": SongData(2900610, "67-0", "Happy Otaku Pack Vol.18", True, 4, 6, 9),
    "Gullinkambi": SongData(2900611, "67-1", "Happy Otaku Pack Vol.18", True, 4, 7, 10),
    "RakiRaki Rebuilders!!!": SongData(2900612, "67-2", "Happy Otaku Pack Vol.18", True, 5, 7, 10),
    "Laniakea": SongData(2900613, "67-3", "Happy Otaku Pack Vol.18", False, 5, 8, 10),
    "OTTAMA GAZER": SongData(2900614, "67-4", "Happy Otaku Pack Vol.18", True, 5, 8, 10),
    "Sleep Tight feat.Macoto": SongData(2900615, "67-5", "Happy Otaku Pack Vol.18", True, 3, 5, 8),
    "New York Back Raise": SongData(2900617, "68-0", "Gambler's Tricks", True, 6, 8, 10),
    "slic.hertz": SongData(2900618, "68-1", "Gambler's Tricks", True, 5, 7, 9),
    "Fuzzy-Navel": SongData(2900619, "68-2", "Gambler's Tricks", True, 6, 8, 10),
    "Swing Edge": SongData(2900620, "68-3", "Gambler's Tricks", True, 4, 8, 10),
    "Twisted Escape": SongData(2900621, "68-4", "Gambler's Tricks", True, 5, 8, 10),
    "Swing Sweet Twee Dance": SongData(2900622, "68-5", "Gambler's Tricks", False, 4, 7, 10),
    "Sanyousei SAY YA!!!": SongData(2900623, "43-42", "MD Plus Project", False, 4, 6, 8),
    "YUKEMURI TAMAONSEN II": SongData(2900624, "43-43", "MD Plus Project", False, 3, 6, 9),
    "Samayoi no mei Amatsu": SongData(2900626, "69-0", "Touhou Mugakudan -III-", False, 4, 6, 9),
    "INTERNET SURVIVOR": SongData(2900627, "69-1", "Touhou Mugakudan -III-", False, 5, 8, 10),
    "Shuki*RaiRai": SongData(2900628, "69-2", "Touhou Mugakudan -III-", False, 5, 7, 9),
    "HELLOHELL": SongData(2900629, "69-3", "Touhou Mugakudan -III-", False, 4, 7, 10),
    "Calamity Fortune": SongData(2900630, "69-4", "Touhou Mugakudan -III-", True, 6, 8, 10),
    "Tsurupettan": SongData(2900631, "69-5", "Touhou Mugakudan -III-", True, 2, 5, 8),
    "Twilight Poems": SongData(2900632, "43-44", "MD Plus Project", True, 3, 6, 8),
    "All My Friends feat. RANASOL": SongData(2900633, "43-45", "MD Plus Project", True, 4, 7, 9),
    "Heartache": SongData(2900634, "43-46", "MD Plus Project", True, 5, 7, 10),
    "Blue Lemonade": SongData(2900635, "43-47", "MD Plus Project", True, 3, 6, 8),
    "Haunted Dance": SongData(2900636, "43-48", "MD Plus Project", False, 6, 9, 11),
    "Hey Vincent.": SongData(2900637, "43-49", "MD Plus Project", True, 6, 8, 10),
    "Meteor feat. TEA": SongData(2900638, "43-50", "MD Plus Project", True, 3, 6, 9),
    "Narcissism Angel": SongData(2900639, "43-51", "MD Plus Project", True, 1, 3, 6),
    "AlterLuna": SongData(2900640, "43-52", "MD Plus Project", True, 6, 8, 11),
    "Niki Tousen": SongData(2900641, "43-53", "MD Plus Project", True, 6, 8, 10),
    "Rettou Joutou": SongData(2900643, "70-0", "Rin Len's Mirrorland", False, 4, 7, 9),
    "Telecaster B-Boy": SongData(2900644, "70-1", "Rin Len's Mirrorland", False, 5, 7, 10),
    "Iya Iya Iya": SongData(2900645, "70-2", "Rin Len's Mirrorland", False, 2, 4, 7),
    "Nee Nee Nee": SongData(2900646, "70-3", "Rin Len's Mirrorland", False, 4, 6, 8),
    "Chaotic Love Revolution": SongData(2900647, "70-4", "Rin Len's Mirrorland", False, 4, 6, 8),
    "Dance of the Corpses": SongData(2900648, "70-5", "Rin Len's Mirrorland", False, 2, 5, 8),
    "Bitter Choco Decoration": SongData(2900649, "70-6", "Rin Len's Mirrorland", False, 3, 6, 9),
    "Dance Robot Dance": SongData(2900650, "70-7", "Rin Len's Mirrorland", False, 4, 7, 10),
    "Sweet Devil": SongData(2900651, "70-8", "Rin Len's Mirrorland", False, 5, 7, 9),
    "Someday'z Coming": SongData(2900652, "70-9", "Rin Len's Mirrorland", False, 5, 7, 9),
    "Yume Ou Mono Yo Secret": SongData(2900653, "0-53", "Default Music", True, 6, 8, 10),
    "Yume Ou Mono Yo": SongData(2900654, "0-54", "Default Music", True, 1, 4, None),
    "Sweet Dream VIVINOS": SongData(2900656, "71-0", "Valentine Stage", False, 1, 4, 7),
    "Ruler Of My Heart VIVINOS": SongData(2900657, "71-1", "Valentine Stage", False, 2, 4, 6),
    "Reality Show": SongData(2900658, "71-2", "Valentine Stage", False, 5, 7, 10),
    "SIG feat.Tobokegao": SongData(2900659, "71-3", "Valentine Stage", True, 3, 6, 8),
    "Rose Love": SongData(2900660, "71-4", "Valentine Stage", True, 2, 4, 7),
    "Euphoria": SongData(2900661, "71-5", "Valentine Stage", True, 1, 3, 6),
    "P E R O P E R O Brother Dance": SongData(2900663, "72-0", "Legends of Muse Warriors", True, None, 7, None),
    "PA PPA PANIC": SongData(2900664, "72-1", "Legends of Muse Warriors", False, 4, 8, 10),
    "How To Make Music Game Song!": SongData(2900665, "72-2", "Legends of Muse Warriors", True, 6, 8, 10),
    "Re Re": SongData(2900666, "72-3", "Legends of Muse Warriors", True, 7, 9, 11),
    "Marmalade Twins": SongData(2900667, "72-4", "Legends of Muse Warriors", True, 5, 8, 10),
    "DOMINATOR": SongData(2900668, "72-5", "Legends of Muse Warriors", True, 7, 9, 11),
    "Teshikani TESHiKANi": SongData(2900669, "72-6", "Legends of Muse Warriors", True, 5, 7, 9),
    "Urban Magic": SongData(2900671, "73-0", "Happy Otaku Pack Vol.19", True, 3, 5, 7),
    "Maid's Prank": SongData(2900672, "73-1", "Happy Otaku Pack Vol.19", True, 5, 7, 10),
    "Dance Dance Good Night Dance": SongData(2900673, "73-2", "Happy Otaku Pack Vol.19", True, 2, 4, 7),
    "Ops Limone": SongData(2900674, "73-3", "Happy Otaku Pack Vol.19", True, 5, 8, 11),
    "NOVA": SongData(2900675, "73-4", "Happy Otaku Pack Vol.19", True, 6, 8, 10),
    "Heaven's Gradius": SongData(2900676, "73-5", "Happy Otaku Pack Vol.19", True, 6, 8, 10),
    "Ray Tuning": SongData(2900678, "74-0", "CHUNITHM COURSE MUSE", True, 6, 8, 10),
    "World Vanquisher": SongData(2900679, "74-1", "CHUNITHM COURSE MUSE", True, 6, 8, 10),
    "Tsukuyomi Ni Naru Replaced": SongData(2900680, "74-2", "CHUNITHM COURSE MUSE", True, 5, 7, 9),
    "The wheel to the right": SongData(2900681, "74-3", "CHUNITHM COURSE MUSE", True, 5, 7, 9),
    "Climax": SongData(2900682, "74-4", "CHUNITHM COURSE MUSE", True, 4, 8, 11),
    "Spider's Thread": SongData(2900683, "74-5", "CHUNITHM COURSE MUSE", True, 5, 8, 10),
    "HIT ME UP": SongData(2900684, "43-54", "MD Plus Project", True, 4, 6, 8),
    "Test Me feat. Uyeon": SongData(2900685, "43-55", "MD Plus Project", True, 3, 5, 9),
    "Assault TAXI": SongData(2900686, "43-56", "MD Plus Project", True, 4, 7, 10),
    "No": SongData(2900687, "43-57", "MD Plus Project", False, 4, 6, 9),
    "Pop it": SongData(2900688, "43-58", "MD Plus Project", True, 1, 3, 6),
    "HEARTBEAT! KyunKyun!": SongData(2900689, "43-59", "MD Plus Project", True, 4, 6, 9),
    "SUPERHERO": SongData(2900691, "75-0", "Novice Rider Pack", False, 2, 4, 7),
    "Highway_Summer": SongData(2900692, "75-1", "Novice Rider Pack", True, 2, 4, 6),
    "Mx. Black Box": SongData(2900693, "75-2", "Novice Rider Pack", True, 5, 7, 9),
    "Sweet Encounter": SongData(2900694, "75-3", "Novice Rider Pack", True, 2, 4, 7),
    "Echo over you... Secret": SongData(2900695, "0-55", "Default Music", False, 6, 8, 10),
    "Echo over you...": SongData(2900696, "0-56", "Default Music", False, 1, 4, None),
    "Tsukuyomi Ni Naru": SongData(2900697, "74-6", "CHUNITHM COURSE MUSE", True, 5, 8, 10),
    "disco light": SongData(2900699, "76-0", "MUSE RADIO FM105", True, 5, 7, 9),
    "room light feat.chancylemon": SongData(2900700, "76-1", "MUSE RADIO FM105", True, 3, 5, 7),
    "Invisible": SongData(2900701, "76-2", "MUSE RADIO FM105", True, 3, 5, 8),
    "Christmas Season-LLABB": SongData(2900702, "76-3", "MUSE RADIO FM105", True, 1, 4, 7),
    "Hyouryu": SongData(2900704, "77-0", "Let's Rhythm Jam!", False, 6, 8, 10),
    "The Whole Rest": SongData(2900705, "77-1", "Let's Rhythm Jam!", False, 5, 8, 10),
    "Hydra": SongData(2900706, "77-2", "Let's Rhythm Jam!", False, 4, 7, 11),
    "Pastel Lines": SongData(2900707, "77-3", "Let's Rhythm Jam!", False, 3, 6, 9),
    "LINK x LIN#S": SongData(2900708, "77-4", "Let's Rhythm Jam!", False, 3, 6, 9),
    "Arcade ViruZ": SongData(2900709, "77-5", "Let's Rhythm Jam!", False, 6, 8, 11),
    "Eve Avenir": SongData(2900711, "78-0", "Endless Pirouette", True, 6, 8, 10),
    "Silverstring": SongData(2900712, "78-1", "Endless Pirouette", True, 5, 7, 10),
    "Melusia": SongData(2900713, "78-2", "Endless Pirouette", False, 5, 7, 10),
    "Devil's Castle": SongData(2900714, "78-3", "Endless Pirouette", True, 4, 7, 10),
    "Abatement": SongData(2900715, "78-4", "Endless Pirouette", True, 6, 8, 10),
    "Azalea": SongData(2900716, "78-5", "Endless Pirouette", False, 4, 8, 10),
    "Brightly World": SongData(2900717, "78-6", "Endless Pirouette", True, 6, 8, 10),
    "We'll meet in every world ***": SongData(2900718, "78-7", "Endless Pirouette", True, 7, 9, 11),
    "Collapsar": SongData(2900719, "78-8", "Endless Pirouette", True, 7, 9, 10),
    "Parousia": SongData(2900720, "78-9", "Endless Pirouette", False, 6, 8, 10),
    "Gunners in the Rain": SongData(2900722, "79-0", "Ensemble Arcanum", False, 5, 8, 10),
    "Halzion": SongData(2900723, "79-1", "Ensemble Arcanum", False, 2, 5, 8),
    "SHOWTIME!!": SongData(2900724, "79-2", "Ensemble Arcanum", False, 6, 8, 10),
    "Achromic Riddle": SongData(2900725, "79-3", "Ensemble Arcanum", False, 6, 8, 10),
    "karanosu": SongData(2900726, "79-4", "Ensemble Arcanum", False, 3, 6, 8),
    "Necromantic": SongData(2900727, "43-60", "MD Plus Project", False, 6, 8, 10),
    "Saishuu kichiku imouto Flandre-S": SongData(2900729, "80-0", "Touhou Mugakudan -IV-", False, 6, 8, 10),
    "Kachoufuugetsu": SongData(2900730, "80-1", "Touhou Mugakudan -IV-", False, 2, 6, 8),
    "Maid heart is a puppet": SongData(2900731, "80-2", "Touhou Mugakudan -IV-", False, 5, 7, 9),
    "Trance dance anarchy": SongData(2900732, "80-3", "Touhou Mugakudan -IV-", False, 4, 7, 10),
    "fairy stage": SongData(2900733, "80-4", "Touhou Mugakudan -IV-", False, 4, 6, 9),
    "Scarlet Police on Ghetto Patrol": SongData(2900734, "80-5", "Touhou Mugakudan -IV-", False, 5, 7, 10),
    "Unwelcome School": SongData(2900735, "81-0", "MD-level Tactical Training Blu-ray", False, 6, 8, 10),
    "Usagi Flap": SongData(2900736, "81-1", "MD-level Tactical Training Blu-ray", False, 3, 6, 8),
    "RE Aoharu": SongData(2900737, "81-2", "MD-level Tactical Training Blu-ray", False, 3, 5, 8),
    "Operation*DOTABATA!": SongData(2900738, "81-3", "MD-level Tactical Training Blu-ray", False, 5, 7, 10),
    "Break Through the Dome": SongData(2900739, "82-0", "MSR Anthology_Vol.02", False, 5, 7, 9),
    "Here in Vernal Terrene": SongData(2900740, "82-1", "MSR Anthology_Vol.02", False, 3, 5, 7),
    "Everything's Alright": SongData(2900741, "82-2", "MSR Anthology_Vol.02", False, 3, 5, 8),
    "Operation Ashring": SongData(2900742, "82-3", "MSR Anthology_Vol.02", False, 3, 5, 7),
    "Misty Memory Day Version": SongData(2900743, "82-4", "MSR Anthology_Vol.02", False, 3, 5, 7),
    "Misty Memory Night Version": SongData(2900744, "82-5", "MSR Anthology_Vol.02", False, 2, 6, 9),
    "Arsonist": SongData(2900745, "82-6", "MSR Anthology_Vol.02", False, 3, 6, 8),
    "Operation Deepness": SongData(2900746, "82-7", "MSR Anthology_Vol.02", False, 2, 4, 6),
    "ALL!!!": SongData(2900747, "82-8", "MSR Anthology_Vol.02", False, 6, 8, 10),
    "LUNATiC CiRCUiT": SongData(2900748, "83-0", "Cosmic Radio 2024", False, 7, 9, 11),
    "Synthesis.": SongData(2900749, "83-1", "Cosmic Radio 2024", True, 6, 8, 10),
    "COSMiC FANFARE!!!!": SongData(2900750, "83-2", "Cosmic Radio 2024", False, 7, 9, 11),
    "Sharp Bubbles": SongData(2900751, "83-3", "Cosmic Radio 2024", True, 7, 9, 11),
    "Replay": SongData(2900752, "83-4", "Cosmic Radio 2024", True, 5, 7, 9),
    "Cosmic Dusty Girl": SongData(2900753, "83-5", "Cosmic Radio 2024", True, 5, 7, 9),
    "Meow Rock feat. Chun Ge, Yuan Shen": SongData(2900754, "84-0", "Muse Dash・Legend", True, None, None, None),
    "Even if you make an old radio song with AI": SongData(2900755, "84-1", "Muse Dash・Legend", False, 3, 6, 8),
    "Unusual Sketchbook": SongData(2900756, "84-2", "Muse Dash・Legend", True, 6, 8, 11),
    "TransientTears": SongData(2900757, "84-3", "Muse Dash・Legend", True, 6, 8, 11),
    "SHOOTING*STAR": SongData(2900758, "84-4", "Muse Dash・Legend", False, 5, 7, 9),
    "But the Blue Bird is Already Dead": SongData(2900759, "84-5", "Muse Dash・Legend", False, 6, 8, 10),
    "Heart Message feat. Aoi Tokimori Secret": SongData(2900760, "0-57", "Default Music", True, None, 7, 10),
    "Heart Message feat. Aoi Tokimori": SongData(2900761, "0-58", "Default Music", True, 1, 3, 6),
    "Aventyr": SongData(2900762, "85-0", "Happy Otaku Pack Vol.20", True, 4, 7, 10),
    "Raintain": SongData(2900763, "85-1", "Happy Otaku Pack Vol.20", False, 6, 8, 10),
    "Piercing the Clouds and Waves": SongData(2900764, "85-2", "Happy Otaku Pack Vol.20", True, 3, 6, 8),
    "Save Yourself": SongData(2900765, "85-3", "Happy Otaku Pack Vol.20", True, 5, 7, 10),
    "Menace": SongData(2900766, "85-4", "Happy Otaku Pack Vol.20", True, 7, 9, 11),
    "Dangling": SongData(2900767, "85-5", "Happy Otaku Pack Vol.20", True, 6, 8, 10),
    "Inverted World": SongData(2900768, "86-0", "Aquaria Cruising Guide", True, 4, 6, 8),
    "Suito": SongData(2900769, "86-1", "Aquaria Cruising Guide", True, 6, 8, 11),
    "The Promised Land": SongData(2900770, "86-2", "Aquaria Cruising Guide", True, 4, 6, 9),
    "Alfheim's faith": SongData(2900771, "86-3", "Aquaria Cruising Guide", True, 6, 8, 11),
    "Heaven's Cage": SongData(2900772, "86-4", "Aquaria Cruising Guide", True, 5, 7, 10),
    "Broomstick adventure!": SongData(2900773, "86-5", "Aquaria Cruising Guide", True, 7, 9, 11),
    "Strong Nurse Buro-chan!": SongData(2900774, "43-61", "MD Plus Project", True, 5, 7, 9),
    "Cubism": SongData(2900775, "43-62", "MD Plus Project", False, 5, 7, 9),
    "Cubibibibism": SongData(2900776, "43-63", "MD Plus Project", False, 6, 8, 10),
    "LET'S TOAST!!": SongData(2900777, "43-64", "MD Plus Project", False, 6, 8, 10),
    "#YamiKawa": SongData(2900778, "43-65", "MD Plus Project", False, 5, 7, 10),
    "Rainy Step": SongData(2900779, "43-66", "MD Plus Project", False, 2, 5, 8),
    "OHOSHIKATSU": SongData(2900780, "43-67", "MD Plus Project", False, 5, 7, 10),
    "Dreamy Day": SongData(2900781, "87-0", "Aim to Be a Rhythm Master!", False, 2, 5, 7),
    "Futropolis": SongData(2900782, "87-1", "Aim to Be a Rhythm Master!", False, 4, 7, 9),
    "Quo Vadis": SongData(2900783, "87-2", "Aim to Be a Rhythm Master!", False, 5, 7, 10),
    "REANIMATE": SongData(2900784, "87-3", "Aim to Be a Rhythm Master!", False, 5, 7, 10),
    "Ineffabilis": SongData(2900785, "87-4", "Aim to Be a Rhythm Master!", False, 3, 7, 10),
    "DaJiaHao": SongData(2900786, "87-5", "Aim to Be a Rhythm Master!", False, 5, 7, 10),
    "Echoes of SeraphiM": SongData(2900787, "87-6", "Aim to Be a Rhythm Master!", False, 5, 8, 10),
    "Othello feat.Uiro": SongData(2900788, "88-0", "MUSE RADIO FM106", True, 3, 5, 7),
    "Midnight Blue": SongData(2900789, "88-1", "MUSE RADIO FM106", True, 2, 5, 7),
    "overwork feat.Woonoo": SongData(2900790, "88-2", "MUSE RADIO FM106", True, 2, 6, 8),
    "SUPER CITYLIGHTS": SongData(2900791, "88-3", "MUSE RADIO FM106", True, 5, 7, 10),
    "Flametide": SongData(2900792, "89-0", "Legendary Voyage, Mystic Treasure", True, 5, 7, 9),
    "Embrace feat. Kiyon": SongData(2900793, "89-1", "Legendary Voyage, Mystic Treasure", True, 2, 5, 8),
    "Magazines feat. Nia Suzune": SongData(2900794, "89-2", "Legendary Voyage, Mystic Treasure", True, 3, 6, 8),
    "Temptation": SongData(2900795, "89-3", "Legendary Voyage, Mystic Treasure", False, 5, 8, 10),
    "PwP": SongData(2900796, "89-4", "Legendary Voyage, Mystic Treasure", True, 3, 6, 9),
    "I Can Show You": SongData(2900797, "89-5", "Legendary Voyage, Mystic Treasure", False, 5, 7, 9),
    "An Artificial Flower Has No Right to Wilt": SongData(2900798, "90-0", "MEDIUM5 Echoes", True, 3, 5, 7),
    "Time Stopped": SongData(2900799, "90-1", "MEDIUM5 Echoes", True, 5, 7, 9),
    "Stranded Siren": SongData(2900800, "90-2", "MEDIUM5 Echoes", True, 6, 8, 10),
    "City Lights": SongData(2900801, "90-3", "MEDIUM5 Echoes", True, 4, 6, 9),
    "Polaris Wandering Night": SongData(2900802, "90-4", "MEDIUM5 Echoes", True, 5, 8, 10),
    "Chasing the Moonlight": SongData(2900803, "90-5", "MEDIUM5 Echoes", True, 4, 6, 8),
    "WILDCARD": SongData(2900804, "91-0", "48 Hours After Discharge", True, 3, 6, 9),
    "It was all just a dream!": SongData(2900805, "91-1", "48 Hours After Discharge", True, 5, 7, 9),
    "Science": SongData(2900806, "91-2", "48 Hours After Discharge", False, 4, 7, 9),
    "Hit Maker": SongData(2900807, "91-3", "48 Hours After Discharge", False, 4, 6, 9),
    "THX 4 playing": SongData(2900808, "91-4", "48 Hours After Discharge", True, 3, 5, 8),
    "Theory of Existence": SongData(2900809, "91-5", "48 Hours After Discharge", True, 4, 6, 9),
}
